@@ -3,7 +3,7 @@ from . import objects as objects
 from . import requests as bot
 from .base import UserProxyModel, Constants, exceptions as exc, UserModel
 from .context import ctx
-from .ext import handle
+from .dispatcher import Dispatcher
 from .loader import logger
 from .run import run
 from .utils import html
